==> org.eclipse.papyrus.customization.properties.source_1.1.3.201511250900.jar: org/eclipse/papyrus/customization/properties/storage/actions/workspace/WorkspaceContextStorageActionProvider.java <==
/*****************************************************************************
 * Copyright (c) 2013 CEA LIST.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   CEA LIST - Initial API and implementation
 *****************************************************************************/
package org.eclipse.papyrus.customization.properties.storage.actions.workspace;

import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.papyrus.customization.properties.storage.actions.AbstractContextStorageActionProvider;
import org.eclipse.papyrus.customization.properties.storage.actions.IContextCopyAction;
import org.eclipse.papyrus.customization.properties.storage.actions.IContextDeleteAction;
import org.eclipse.papyrus.customization.properties.storage.actions.IContextEditAction;
import org.eclipse.papyrus.views.properties.contexts.Context;


/**
 * This is the WorkspaceContextStorageActionProvider type. Enjoy.
 */
public class WorkspaceContextStorageActionProvider extends AbstractContextStorageActionProvider {

	public WorkspaceContextStorageActionProvider() {
		super();
	}

	@Override
	public boolean providesFor(Context context) {
		Resource resource = context.eResource();
		return (resource != null) && resource.getURI().isPlatformResource() || resource.getURI().isFile();
	}

	@Override
	protected IContextCopyAction createContextCopyAction() {
		return new WorkspaceContextCopyAction();
	}

	@Override
	protected IContextEditAction createContextEditAction() {
		return new WorkspaceContextEditAction();
	}

	@Override
	protected IContextDeleteAction createContextDeleteAction() {
		return new WorkspaceContextDeleteAction();
	}

}

==> org.eclipse.papyrus.customization.properties.source_2.0.0.201703080851.jar: org/eclipse/papyrus/customization/properties/storage/actions/workspace/WorkspaceContextStorageActionProvider.java <==
/*****************************************************************************
 * Copyright (c) 2013 CEA LIST.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   CEA LIST - Initial API and implementation
 *****************************************************************************/
package org.eclipse.papyrus.customization.properties.storage.actions.workspace;

import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.papyrus.customization.properties.storage.actions.AbstractContextStorageActionProvider;
import org.eclipse.papyrus.customization.properties.storage.actions.IContextCopyAction;
import org.eclipse.papyrus.customization.properties.storage.actions.IContextDeleteAction;
import org.eclipse.papyrus.customization.properties.storage.actions.IContextEditAction;
import org.eclipse.papyrus.infra.properties.contexts.Context;


/**
 * This is the WorkspaceContextStorageActionProvider type. Enjoy.
 */
public class WorkspaceContextStorageActionProvider extends AbstractContextStorageActionProvider {

	public WorkspaceContextStorageActionProvider() {
		super();
	}

	@Override
	public boolean providesFor(Context context) {
		Resource resource = context.eResource();
		return (resource != null) && resource.getURI().isPlatformResource() || resource.getURI().isFile();
	}

	@Override
	protected IContextCopyAction createContextCopyAction() {
		return new WorkspaceContextCopyAction();
	}

	@Override
	protected IContextEditAction createContextEditAction() {
		return new WorkspaceContextEditAction();
	}

	@Override
	protected IContextDeleteAction createContextDeleteAction() {
		return new WorkspaceContextDeleteAction();
	}

}
